ListResourceResponseItem

Struct ListResourceResponseItem 

pub struct ListResourceResponseItem {
    pub endpoints: Option<HashMap<String, Vec<i32>>>,
    pub resource: Option<String>,
}
The list response item that contains the resource and end points information.

This type is not used in any activity, and only used as part of another schema.

Fields

endpoints: Option<HashMap<String, Vec<i32>>>

The list of service end points on the resource.

resource: Option<String>

The full URL of the resource.