pub struct ZoneViewsGetServiceResponse {
pub endpoints: Option<Vec<ServiceEndpoint>>,
pub fingerprint: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get service zone views (response)
Fields
endpoints: Option<Vec<ServiceEndpoint>>The service information.
fingerprint: Option<String>The fingerprint of the service information.