pub struct ZoneViewsList {
pub items: Option<Vec<ResourceView>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
}Expand description
The response to a list request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list zone views (response)
Fields
items: Option<Vec<ResourceView>>The result that contains all resource views that meet the criteria.
kind: Option<String>Type of resource.
next_page_token: Option<String>A token used for pagination.
self_link: Option<String>Server defined URL for this resource (output only).