pub struct ZoneViewsListResourcesResponse {
pub items: Option<Vec<ListResourceResponseItem>>,
pub network: Option<String>,
pub next_page_token: Option<String>,
}Expand description
The response to a list resource request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list resources zone views (response)
Fields
items: Option<Vec<ListResourceResponseItem>>The formatted JSON that is requested by the user.
network: Option<String>The URL of a Compute Engine network to which the resources in the view belong.
next_page_token: Option<String>A token used for pagination.